@@ -1,8 +1,9 @@
 package Message::Passing::Filter::Delay;
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw( :all );
 use AnyEvent;
 use Scalar::Util qw/ weaken /;
-use namespace::autoclean;
+use namespace::clean -except => 'meta';
 
 with qw/
     Message::Passing::Role::Input
@@ -10,7 +11,7 @@ with qw/
 /;
 
 has delay_for => (
-    isa => 'Num',
+    isa => Num,
     is => 'ro',
     required => 1,
 );
@@ -27,7 +28,7 @@ sub consume {
     );
 }
 
-__PACKAGE__->meta->make_immutable;
+
 1;
 
 =head1 NAME
