@@ -1,26 +1,26 @@
 package Message::Passing::Filter::Key;
-use Moose;
-use Moose::Util::TypeConstraints;
-use namespace::autoclean;
+use Moo;
+use MooX::Types::MooseLike::Base qw/ Str /;
+use namespace::clean -except => 'meta';
 
 with 'Message::Passing::Role::Filter';
 
 has key => (
-    isa => 'Str',
+    isa => Str,
     is => 'ro',
     required => 1,
 );
 
 has match => (
-    isa => 'Str',
+    isa => Str,
     is => 'ro',
     required => 1,
 );
 
 has match_type => (
     is => 'ro',
-    isa => enum(['regex', 'eq']),
-    default => 'eq',
+#    isa => enum(['regex', 'eq']),
+    default => sub { 'eq' },
 );
 
 has _re => (
@@ -51,7 +51,7 @@ sub filter {
     return $message;
 }
 
-__PACKAGE__->meta->make_immutable;
+
 1;
 
 =head1 NAME
