@@ -1,12 +1,12 @@
 package Message::Passing::Output::Null;
-use Moose;
-use namespace::autoclean;
+use Moo;
+use namespace::clean -except => 'meta';
 
 with 'Message::Passing::Role::Output';
 
 sub consume {}
 
-__PACKAGE__->meta->make_immutable;
+
 1;
 
 =head1 NAME
