@@ -1,10 +1,9 @@
 package Message::Passing::Role::HasErrorChain;
-use Moose::Role;
+use Moo::Role;
 use Message::Passing::Output::STDERR;
-use namespace::autoclean;
+use namespace::clean -except => 'meta';
 
 has error => (
-    does => 'Message::Passing::Role::Output',
     is => 'ro',
     default => sub {
         Message::Passing::Output::STDERR->new;
@@ -21,23 +20,29 @@ Message::Passing::Role::HasErrorChain - A role for components which can report e
 
     # Note this is an example package, and does not really exist!
     package Message::Passing::Output::ErrorAllMessages;
-    use Moose;
-    use namespace::autoclean;
-    
+    use Moo;
+    use namespace::clean -except => 'meta';
+
     with qw/
         Message::Passing::Role::Output
         Message::Passing::Role::HasErrorChain
     /;
-    
+
     sub consume {
         my ($self, $message) = @_;
         $self->error->consume($message);
     }
-    
+
 =head1 DESCRIPTION
 
 Some components can create an error stream in addition to a message stream.
 
+=head1 METHODS
+
+=head2 error
+
+An attribute containing the error chain.
+
 =head1 SPONSORSHIP
 
 This module exists due to the wonderful people at Suretec Systems Ltd.
